#include <stdlib.h>
#include <stdio.h>

#include <tpro.h>

int main (int argc, char *argv[])
{
    char           deviceName[32];
    int            retVal;
    TPRO_BoardObj *pBoard;
    TPRO_TimeObj   tproTime;
    unsigned char  rv;

    retVal = 0;
    
    /* If invalid number of arguments... */
    if (argc != 2) 
    {
        printf(" Usage: GetTime <device index>\n");
        return (1);
    }
    
    /* Construct the TPRO/TSAT device name */
    sprintf(deviceName, "/dev/tpropci%d", atoi(argv[1]));
    
    /* Open the TPRO/TSAT device */
    rv = TPRO_open(&pBoard, deviceName);
    
    /* If unable to open the TPRO/TSAT device... */
    if (rv != TPRO_SUCCESS) 
    {
        printf (" Could Not Open '%s'!! [%d]\n", deviceName, rv);
        return (1);
    }

    /* Get the TPRO/TSAT current time */
    rv = TPRO_getTime(pBoard, &tproTime);
    
    /* If unable to get the TPRO/TSAT current time... */
    if (rv != TPRO_SUCCESS) 
    {
        printf (" Could not retrieve time from '%s'!! [%d]\n", deviceName, rv);
        retVal = 1;
    }
    else
    {
        /* Display the TPRO/TSAT current time */
        printf (" Device Name: %s\n", deviceName);
        printf (" Days:        %d\n", tproTime.days);
        printf (" Hours:       %d\n", tproTime.hours);
        printf (" Minutes:     %d\n", tproTime.minutes);
        printf (" Seconds:     %f\n", tproTime.secsDouble);

        if ( (pBoard->options == 0x7000) || (pBoard->options == 0x7100) ||
             (pBoard->options == 0x7200) || (pBoard->options == 0x7300) ) {
             printf (" Year:        %d\n", tproTime.year);
        }


	if ((tproTime.flags & 0x8000) == 0)
	{
	    printf (" TCODE:       %d\n", (tproTime.flags & 0x2)? 1:0);
	    printf (" SYNC:        %d\n", (tproTime.flags & 0x4)? 1:0);
	}
    }

    /* Close the TPRO/TSAT device */
    rv = TPRO_close(pBoard);
    
    /* If unable to close the TPRO/TSAT device... */
    if (rv != TPRO_SUCCESS) 
    {
        printf (" Could Not Close Board!! [%d]\n", rv);
        retVal = 1;
    }

    return (retVal);

} /* End - main() */
