#include <stdlib.h>
#include <stdio.h>

#include <tpro.h>

int main (int argc, char *argv[])
{
    char           deviceName[32];
    unsigned char  frequency;
    int            retVal;
    TPRO_BoardObj *pBoard;
    unsigned char  rv;
    
    retVal = 0;

    /* If invalid number of arguments... */
    if (argc != 3) 
    {
        printf(" Usage: SetOsc <device index> <frequency> 0=off,1=1KHz,2=1MHz,3=5MHz,4=10MHz\n");
        return (1);
    }

    /* Construct the TPRO/TSAT device name */
    sprintf(deviceName, "/dev/tpropci%d", atoi(argv[1]));
    
    /* Read frequency setting argument for cPCI board */
    sscanf (argv[2], "%c", &frequency);

     
    /* Open the TPRO/TSAT device */
    rv = TPRO_open(&pBoard, deviceName);
    
    /* If unable to open the TPRO/TSAT device... */
    if (rv != TPRO_SUCCESS) 
    {
        printf(" Could Not Open Board '%s'!! [%d]\n", deviceName, rv);
        return (1);
    }

    /* Wait until this handle is the first user of the device. */
    if (TPRO_setPropDelayCorr(pBoard, NULL) != TPRO_SUCCESS) 
    {
        printf(" Waiting to become first user...\n");
        while (TPRO_setPropDelayCorr(pBoard, NULL) != TPRO_SUCCESS);
    }

    /* Set the TPRO/TSAT propagation delay */
    rv = TPRO_setOscillator(pBoard, &frequency);
    
    /* If unable to set the cPCI/PMC Frequency... */
    if (rv != TPRO_SUCCESS) 
    {
        printf(" Could Not Set Frequency!! [%d]\n", rv);
        retVal = 1;
    }

    /* Close the TPRO/TSAT device */
    rv = TPRO_close(pBoard);
    
    /* If unable to close the TPRO/TSAT device... */
    if (rv != TPRO_SUCCESS) 
    {
        printf(" Could Not Close Board!! [%d]\n", rv);
        retVal = 1;
    }

    return (retVal);

} /* End - main() */
