#include <stdio.h>
#include <stdlib.h>

#include <tpro.h>

int main (int argc, char *argv[])
{
    char           deviceName[32];
    int            retVal;
    int            tmp;
    TPRO_BoardObj *pBoard;
    TPRO_TimeObj   tproTime = {0};
    unsigned char  rv;

    retVal = 0;

    if (argc < 2)
    {
        printf(" Usage: SetTime <device index> <TIME>\n");
        return (1);
    }

    /* Construct the TPRO/TSAT device name */
    sprintf(deviceName, "/dev/tpropci%d", atoi(argv[1]));

    /* Open the TPRO/TSAT device */
    rv = TPRO_open(&pBoard, deviceName);
    
    /* If unable to open the TPRO/TSAT device... */
    if (rv != TPRO_SUCCESS) 
    {
        printf(" Could Not Open Board '%s'!! [%d]\n", deviceName, rv);
        return (1);
    }

    // If Compact PCI / PMC and invalid number of arguments
    if ((pBoard->options == 0x7000) ||
        (pBoard->options == 0x7100) ||
        (pBoard->options == 0x7200) ||
        (pBoard->options == 0x7300))
    {
        if (argc != 7)
        {
            printf(" Usage: SetTime <device index> <year> <days> <hours> <minutes> "
                   "<seconds>\n");

            /* Close the TPRO/TSAT device */
            rv = TPRO_close(pBoard);
    
            /* If unable to close the TPRO/TSAT device */
            if (rv != TPRO_SUCCESS) 
            {
                printf(" Could Not Close Board!! [%d]\n", rv);
            }

            return (1);
        }
    }
    else
    {
        /* Else if invalid number of arguments... */
        if (argc != 6)
        {
            printf(" Usage: SetTime <device index> <days> <hours> <minutes> "
                   "<seconds>\n");

            /* Close the TPRO/TSAT device */
            rv = TPRO_close(pBoard);
    
            /* If unable to close the TPRO/TSAT device */
            if (rv != TPRO_SUCCESS) 
            {
                printf(" Could Not Close Board!! [%d]\n", rv);
            }

            return (1);
        }
    }
    
    /*
    **  read into time object
    */
    if ((pBoard->options == 0x7000) ||
        (pBoard->options == 0x7100) ||
        (pBoard->options == 0x7200) ||
        (pBoard->options == 0x7300))
    {
        sscanf (argv[2], "%d", &tmp);
        tproTime.year = (unsigned short) tmp;

        sscanf (argv[3], "%d", &tmp);
        tproTime.days = (unsigned short) tmp;

        sscanf (argv[4], "%d", &tmp);
        tproTime.hours = (unsigned char) tmp;

        sscanf (argv[5], "%d", &tmp);
        tproTime.minutes = (unsigned char) tmp;

        sscanf (argv[6], "%d", &tmp);
        tproTime.seconds = (unsigned char) tmp;
    }
    else
    {
        sscanf (argv[2], "%d", &tmp);
        tproTime.days = (unsigned short) tmp;

        sscanf (argv[3], "%d", &tmp);
        tproTime.hours = (unsigned char) tmp;

        sscanf (argv[4], "%d", &tmp);
        tproTime.minutes = (unsigned char) tmp;

        sscanf (argv[5], "%d", &tmp);
        tproTime.seconds = (unsigned char) tmp;
    }

    /* Wait until this handle is the first user of the device. */
    if (TPRO_setPropDelayCorr(pBoard, NULL) != TPRO_SUCCESS) 
    {
        printf(" Waiting to become first user...\n");
        while (TPRO_setPropDelayCorr(pBoard, NULL) != TPRO_SUCCESS);
    }

    /* Set the TPRO/TSAT current time */
    rv = TPRO_setTime(pBoard, &tproTime);
    
    /* If unable to set the TPRO/TSAT current time... */
    if (rv != TPRO_SUCCESS) 
    {
        printf(" Could not set time!! [%d]\n", rv);
        retVal = 1;
    }

    /* Close the TPRO/TSAT device */
    rv = TPRO_close(pBoard);
    
    /* If unable to close the TPRO/TSAT device */
    if (rv != TPRO_SUCCESS) 
    {
        printf(" Could Not Close Board!! [%d]\n", rv);
        retVal = 1;
    }

    return (retVal);

} /* End - main() */
