#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>

#include <tpro.h>

int main (int argc, char *argv[])
{
    char           deviceName[32];
    int            pid;
    int            retVal;
    TPRO_BoardObj *pBoard;
    TPRO_WaitObj   WaitObj;
    unsigned char  rv;

    retVal = 0;
    
    /* If invalid number of arguments... */
    if (argc != 2) 
    {
        printf(" Usage: WaitEvent <device index>\n");
        return (1);
    }

    /* Construct the TPRO/TSAT device name */
    sprintf(deviceName, "/dev/tpropci%d", atoi(argv[1]));
    
    /* Open the TPRO/TSAT device */
    rv = TPRO_open(&pBoard, deviceName);
    
    /* If unable to open the TPRO/TSAT device... */
    if (rv != TPRO_SUCCESS) 
    {
        printf(" Could Not Open Board '%s'!! [%d]\n", deviceName, rv);
        return (1);
    }


        /*
        **  wait for external time-tag event
        */
        printf(" Waiting for event.......");
        fflush (stdout);
        WaitObj.jiffies = 10 * 1000;	/** 10 seconds **/
        rv = TPRO_waitEvent (pBoard, &WaitObj);
        
        switch (rv) {

        case TPRO_SUCCESS:
          printf(" Received Interrupt\n");
          printf("   Days: %d\n", WaitObj.days);
          printf("   Hours: %d\n", WaitObj.hours);
          printf("   Minutes: %d\n", WaitObj.minutes);
          printf("   Seconds: %f\n", WaitObj.seconds);
          break;

        case TPRO_TIMEOUT_ERR:
          printf(" Timeout Waiting for Time-tagged Event!!\n\n");
          retVal = 1;
          break;

        case TPRO_COMM_ERR:
          printf(" Error Communicating With Timing Board!!\n\n");
          retVal = 1;
          break;
        }


    /* Close the TPRO/TSAT device */
    rv = TPRO_close(pBoard);
    
    /* If unable to close the TPRO/TSAT device... */
    if (rv != TPRO_SUCCESS) 
    {
        printf(" Could Not Close Board!! [%d]\n", rv);
        retVal = 1;
    }

    return (retVal);

} /* End - main() */
